# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from qm.pb import job_manager_pb2 as qm_dot_pb_dot_job__manager__pb2


class JobManagerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetElementCorrection = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/GetElementCorrection',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.GetElementCorrectionRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.GetElementCorrectionResponse.FromString,
                )
        self.SetElementCorrection = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/SetElementCorrection',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.SetElementCorrectionRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.SetElementCorrectionResponse.FromString,
                )
        self.GetDigitalInputPolarity = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/GetDigitalInputPolarity',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputPolarityRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputPolarityResponse.FromString,
                )
        self.SetDigitalInputPolarity = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/SetDigitalInputPolarity',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputPolarityRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputPolarityResponse.FromString,
                )
        self.GetDigitalInputWindow = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/GetDigitalInputWindow',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputWindowRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputWindowResponse.FromString,
                )
        self.SetDigitalInputWindow = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/SetDigitalInputWindow',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputWindowRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputWindowResponse.FromString,
                )
        self.GetDigitalInputThreshold = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/GetDigitalInputThreshold',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputThresholdRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputThresholdResponse.FromString,
                )
        self.SetDigitalInputThreshold = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/SetDigitalInputThreshold',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputThresholdRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputThresholdResponse.FromString,
                )
        self.InsertInputStream = channel.unary_unary(
                '/qm.grpc.jobManager.JobManagerService/InsertInputStream',
                request_serializer=qm_dot_pb_dot_job__manager__pb2.InsertInputStreamRequest.SerializeToString,
                response_deserializer=qm_dot_pb_dot_job__manager__pb2.InsertInputStreamResponse.FromString,
                )


class JobManagerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetElementCorrection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetElementCorrection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDigitalInputPolarity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDigitalInputPolarity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDigitalInputWindow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDigitalInputWindow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDigitalInputThreshold(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDigitalInputThreshold(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsertInputStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobManagerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetElementCorrection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetElementCorrection,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.GetElementCorrectionRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.GetElementCorrectionResponse.SerializeToString,
            ),
            'SetElementCorrection': grpc.unary_unary_rpc_method_handler(
                    servicer.SetElementCorrection,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.SetElementCorrectionRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.SetElementCorrectionResponse.SerializeToString,
            ),
            'GetDigitalInputPolarity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDigitalInputPolarity,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputPolarityRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputPolarityResponse.SerializeToString,
            ),
            'SetDigitalInputPolarity': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDigitalInputPolarity,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputPolarityRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputPolarityResponse.SerializeToString,
            ),
            'GetDigitalInputWindow': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDigitalInputWindow,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputWindowRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputWindowResponse.SerializeToString,
            ),
            'SetDigitalInputWindow': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDigitalInputWindow,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputWindowRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputWindowResponse.SerializeToString,
            ),
            'GetDigitalInputThreshold': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDigitalInputThreshold,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputThresholdRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.GetDigitalInputThresholdResponse.SerializeToString,
            ),
            'SetDigitalInputThreshold': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDigitalInputThreshold,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputThresholdRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.SetDigitalInputThresholdResponse.SerializeToString,
            ),
            'InsertInputStream': grpc.unary_unary_rpc_method_handler(
                    servicer.InsertInputStream,
                    request_deserializer=qm_dot_pb_dot_job__manager__pb2.InsertInputStreamRequest.FromString,
                    response_serializer=qm_dot_pb_dot_job__manager__pb2.InsertInputStreamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qm.grpc.jobManager.JobManagerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class JobManagerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetElementCorrection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/GetElementCorrection',
            qm_dot_pb_dot_job__manager__pb2.GetElementCorrectionRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.GetElementCorrectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetElementCorrection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/SetElementCorrection',
            qm_dot_pb_dot_job__manager__pb2.SetElementCorrectionRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.SetElementCorrectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDigitalInputPolarity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/GetDigitalInputPolarity',
            qm_dot_pb_dot_job__manager__pb2.GetDigitalInputPolarityRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.GetDigitalInputPolarityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDigitalInputPolarity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/SetDigitalInputPolarity',
            qm_dot_pb_dot_job__manager__pb2.SetDigitalInputPolarityRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.SetDigitalInputPolarityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDigitalInputWindow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/GetDigitalInputWindow',
            qm_dot_pb_dot_job__manager__pb2.GetDigitalInputWindowRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.GetDigitalInputWindowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDigitalInputWindow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/SetDigitalInputWindow',
            qm_dot_pb_dot_job__manager__pb2.SetDigitalInputWindowRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.SetDigitalInputWindowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDigitalInputThreshold(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/GetDigitalInputThreshold',
            qm_dot_pb_dot_job__manager__pb2.GetDigitalInputThresholdRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.GetDigitalInputThresholdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDigitalInputThreshold(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/SetDigitalInputThreshold',
            qm_dot_pb_dot_job__manager__pb2.SetDigitalInputThresholdRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.SetDigitalInputThresholdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsertInputStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qm.grpc.jobManager.JobManagerService/InsertInputStream',
            qm_dot_pb_dot_job__manager__pb2.InsertInputStreamRequest.SerializeToString,
            qm_dot_pb_dot_job__manager__pb2.InsertInputStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
